@@ -166,8 +166,6 @@ class DreamBoothDataset(Dataset):
         ).input_ids
 
         if self.class_data_dir:
-            print('triggered at if self.class_data_dir')
-            print('self.num_class_images: ', self.num_class_images)
             class_image = Image.open(self.class_images_path[index % self.num_class_images])
             if not class_image.mode == "RGB":
                 class_image = class_image.convert("RGB")
@@ -326,9 +324,6 @@ class DreamBoothRunner():
         print('='*50)
         self.config = DreamBoothConfig
 
-        # Print some basic info about what we're doing as a sanity check
-        print(f'Training DreamBooth ')
-
         if self.config.seed is not None:
             print(f'Setting seed to {self.config.seed}')
             set_seed(self.config.seed)
@@ -369,7 +364,6 @@ class DreamBoothRunner():
                     if "epoch_*" not in gitignore:
                         gitignore.write("epoch_*\n")
             elif self.config.model_out_dir is not None:
-                print('hit condition line 355')
                 os.makedirs(self.config.model_out_dir, exist_ok=True)
 
 
@@ -424,7 +418,7 @@ class DreamBoothRunner():
         # Use 8-bit Adam for lower memory usage or to fine-tune the model in 16GB GPUs
         print('Setting optimizer class')
         if self.config.use_8bit_adam:
-            print('hit condition use 8bit adam')
+            print('Using 8bit adam')
             try:
                 import bitsandbytes as bnb
             except ImportError:
@@ -434,7 +428,7 @@ class DreamBoothRunner():
 
             self.optimizer_class = bnb.optim.AdamW8bit
         else:
-            print('not using 8bit adam')
+            print('Not using 8bit adam')
             self.optimizer_class = torch.optim.AdamW
 
         print('Getting optimizer')
@@ -450,7 +444,6 @@ class DreamBoothRunner():
             eps=self.config.adam_epsilon,
         )
 
-        print('within __init__(), triggering self.generate_class_images() prior to making the dataloader')
         if self.config.do_prior_preservation:
             self.generate_class_images()
 
@@ -510,15 +503,10 @@ class DreamBoothRunner():
         print('Determining number of training steps')
         # Scheduler and math around the number of training steps.
         overrode_max_train_steps = False
-        print('len(self.train_dataloader):', len(self.train_dataloader))
-        print('self.config.gradient_accumulation_steps:', self.config.gradient_accumulation_steps)
         num_update_steps_per_epoch = math.ceil(len(self.train_dataloader) / self.config.gradient_accumulation_steps)
-        print('num_update_steps_per_epoch:', num_update_steps_per_epoch)
         if self.config.max_train_steps is None:
             self.config.max_train_steps = self.config.num_train_epochs * num_update_steps_per_epoch
             overrode_max_train_steps = True
-        print('max_train_steps:', self.config.max_train_steps)
-        print('overrode_max_train_steps:', overrode_max_train_steps)
 
         print('Getting lr_scheduler')
         self.lr_scheduler = get_scheduler(
@@ -772,7 +760,7 @@ class DreamBoothRunner():
 
             if self.config.push_to_hub:
                 print('Pushing to hub...')
-                self.repo.push_to_hub(commit_message="End of training", blocking=False, auto_lfs_prune=True)
+                self.repo.push_to_hub(commit_message="End of training", blocking=False, auto_lfs_prune=True, clean_ok=False)
                 print('Pushed to hub')
 
         self.accelerator.end_training()
